---------------------------------------------------------------------------
-- Design unit:   True random number generator                           --
--                with Cypress EZ-USB2 FX2 16-bit interface              -- 
---------------------------------------------------------------------------
-- File name:     transfer2usb.vhd                                           --
---------------------------------------------------------------------------
-- System: VHDL'93                                                       --
---------------------------------------------------------------------------
-- Authors:                                                              --
-- Fischer V.                                                            --
-- (C) 2012 Laboratoire Hubert Curien                                    --
---------------------------------------------------------------------------
-- Description:   The block transfer2usb ...                                 --
---------------------------------------------------------------------------
-- Parameters:                                                           --
---------------------------------------------------------------------------
-- Inputs :                                                              --
--    * clk_in       : system clock                                      --
--    * syst_rst     : system global reset                               --
--    * pwr_detect   : VCC detection                                     --
--                                                                       --
-- Inputs/outputs:                                                       --
--    * fd           : 16-bit bi-directional data bus                    --
--                                                                       --
-- Outputs :                                                             --
--    * res_cyp      : reset Cypress EZ-USB (during FPGA configuration)  --
--    * clk_usbif_out: clock output to the Cypress EZ-USB i/f            --
--    * n_sloe       : FX2 data bus output enable                        --
--    * n_slrd       : FX2 USB2local FIFO read enable signal             --
--    * n_slwr       : FX2 local2USB FIFO write enable signal            --
--    * fifo_adr     : 2-bit FIFO select: "00" USB2local, "10" local2USB --
--    * n_pktend     : forced flush of local2USB FIFO in FX2             --
--                                                                       --
---------------------------------------------------------------------------
-- Version: 0.0.1.01, March 2013                                         --
---------------------------------------------------------------------------
-- Revision history:                                                     --
-- Modifications in Version 1.01 made by VF in ...:                      --
--                                                                       --
-- Remarks:   -------------------------------------------------------------
-- A pll should be used to output the interface clock (ifclk) to the     --
-- ez-usb. It is necessary to make ifclk 5 ns earlier than clk.          --
---------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.std_logic_unsigned.ALL;
USE ieee.std_logic_arith.ALL;

Library UNISIM;
use UNISIM.vcomponents.all;

--LIBRARY work;
--USE work.lab_hc_pkg.ALL;

ENTITY Tero_inst IS
PORT
  (
  enable         : IN std_logic;
  output_test	  : OUT STD_LOGIC
 );
END Tero_inst;

ARCHITECTURE rtl OF Tero_inst IS

--Component LUT6 is 
--generic(
--	INIT : std_logic_vector(63 downto 0) := X"0000000000000000"
--);
--port(
--	I0 : in std_logic;
--	I1 : in std_logic;
--	I2 : in std_logic;
--	I3 : in std_logic;
--	I4 : in std_logic;
--	I5 : in std_logic;
--	O  : out std_logic
--);
--end component;
--
--signal and_1, and_2 : std_logic;
--signal not_1_1, not_1_2, not_1_3, not_1_4, not_1_5, not_1_6, not_1_7 : std_logic;
--signal not_2_1, not_2_2, not_2_3, not_2_4, not_2_5, not_2_6, not_2_7 : std_logic;

COMPONENT Tero_SLX_7inv IS
PORT
  (
  enable         : IN std_logic;
  output	  : OUT STD_LOGIC
 );
END COMPONENT;


BEGIN
-----
-- Test de la Hard Macro
-----
UUT : Tero_SLX_7inv port map(
	enable => enable,
	output => output_test
);

------
--	Chaine 1
------

--Chaine_1_and : LUT6 
--generic map (
--	INIT => x"AAAAAAAA00000000") -- I0 and I5.
--port map(
--	I0 => enable,
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_7,
--	O  => and_1
--);
--
--Chaine_1_not_1 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => and_1,
--	O  => not_1_1
--);
--
--Chaine_1_not_2 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_1,
--	O  => not_1_2
--);
--
--Chaine_1_not_3 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_2,
--	O  => not_1_3
--);
--
--Chaine_1_not_4 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_3,
--	O  => not_1_4
--);
--
--Chaine_1_not_5 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_3,
--	O  => not_1_5
--);
--
--Chaine_1_not_6 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_5,
--	O  => not_1_6
--);
--
--Chaine_1_not_7 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_6,
--	O  => not_1_7
--);
--
--------
----	Chaine 2
--------
--
--Chaine_2_and : LUT6 
--generic map (
--	INIT => x"AAAAAAAA00000000") -- I0 and I5.
--port map(
--	I0 => enable,
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_1_7,
--	O  => and_2
--);
--
--Chaine_2_not_1 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => and_2,
--	O  => not_2_1
--);
--
--Chaine_2_not_2 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_1,
--	O  => not_2_2
--);
--
--Chaine_2_not_3 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_2,
--	O  => not_2_3
--);
--
--Chaine_2_not_4 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_3,
--	O  => not_2_4
--);
--
--Chaine_2_not_5 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_3,
--	O  => not_2_5
--);
--
--Chaine_2_not_6 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_5,
--	O  => not_2_6
--);
--
--
--Chaine_2_not_7 : LUT6 
--generic map (
--	INIT => x"00000000ffffffff") -- Not I5.
--port map(
--	I0 => '0',
--	I1 => '0',
--	I2 => '0',
--	I3 => '0',
--	I4 => '0',
--	I5 => not_2_6,
--	O  => not_2_7
--);
--
--output_test <= not_1_7;

END rtl;