---------------------------------------------------------------------
--
-- Design unit:   Package of constants for vhdl modules
--
-- File name:     lab_hc_pkg.vhd
--
-- Description:   This package defines common types, subtypes and
--                constants required to implement building blocks
--                of Hubert Curien laboratory designs in VHDL.
--                Important constants:
--                   - version number
--
-- System:        VHDL'93
--
-- Autor:         Viktor Fischer, Hubert Curien Laboratory, France
--
-- Copyright:     Hubert Curien Laboratory
--
-- Revision:      Version 1.00, May 2013
--
-- Last changes:  - ...
--
---------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.numeric_std.ALL;
USE ieee.std_logic_arith.ALL;

PACKAGE lab_hc_pkg IS                                               
--------------------------------------------------------------------------
------      Application version (will be in the state word)    -----------
--------------------------------------------------------------------------
  CONSTANT VERSION     : STD_LOGIC_VECTOR(15 DOWNTO 0) := X"0101"; 

--------------------------------------------------------------------------
------      Application  parameters  -------------------------------------
--------------------------------------------------------------------------


--------------------------------------------------------------------------
-----   Type, sub-type and constant declarations for general use  --------
--------------------------------------------------------------------------
  SUBTYPE SLV_1_0      IS STD_LOGIC_VECTOR(1 DOWNTO 0);
  SUBTYPE SLV_2_0      IS STD_LOGIC_VECTOR(2 DOWNTO 0);
  SUBTYPE SLV_3_0      IS STD_LOGIC_VECTOR(3 DOWNTO 0);
  SUBTYPE SLV_4_0      IS STD_LOGIC_VECTOR(4 DOWNTO 0);
  SUBTYPE SLV_5_0      IS STD_LOGIC_VECTOR(5 DOWNTO 0);
  SUBTYPE SLV_6_0      IS STD_LOGIC_VECTOR(6 DOWNTO 0);
  SUBTYPE SLV_7_0      IS STD_LOGIC_VECTOR(7 DOWNTO 0);
  SUBTYPE SLV_8_0      IS STD_LOGIC_VECTOR(8 DOWNTO 0);
  SUBTYPE SLV_9_0      IS STD_LOGIC_VECTOR(9 DOWNTO 0);
  SUBTYPE SLV_11_0     IS STD_LOGIC_VECTOR(11 DOWNTO 0);
  SUBTYPE SLV_12_0     IS STD_LOGIC_VECTOR(12 DOWNTO 0);
  SUBTYPE SLV_13_0     IS STD_LOGIC_VECTOR(13 DOWNTO 0);
  SUBTYPE SLV_15_0     IS STD_LOGIC_VECTOR(15 DOWNTO 0);
  SUBTYPE SLV_16_0     IS STD_LOGIC_VECTOR(16 DOWNTO 0);
  SUBTYPE SLV_31_0     IS STD_LOGIC_VECTOR(31 DOWNTO 0);
  SUBTYPE SLV_127_0    IS STD_LOGIC_VECTOR(127 DOWNTO 0);

  
--------------------------------------------------------------------------
-----     Application states codes     -----------------------------------
--------------------------------------------------------------------------

--  User states (USS) ----------------------------------------------------
  CONSTANT USS_IDLE       : SLV_3_0 := "0000"; -- 0
  CONSTANT USS_CONFIG     : SLV_3_0 := "0011"; -- 3 - Config
  CONSTANT USS_START	  : SLV_3_0 := "0111"; -- 7 - Data acquisition
  CONSTANT USS_READ		  : SLV_3_0 := "0001"; -- 1 - Read data
  CONSTANT ERR            : SLV_3_0 := "1111"; -- F - Error flag

----------------------------------------------------------------------------------------
-- Modes
----------------------------------------------------------------------------------------
  CONSTANT MODE_IDLE     : SLV_2_0 := "000"; -- 0 - Idle mode
  CONSTANT MODE_CONFIG   : SLV_2_0 := "011"; -- 3 - Config
  CONSTANT MODE_START    : SLV_2_0 := "111"; -- 7 - Data acquisition
  
----------------------------------------------------------------------------------------
-- Commands
----------------------------------------------------------------------------------------
  CONSTANT NO_COMMAND   : SLV_2_0 := "000"; -- 0 - No command

END lab_hc_pkg;